
#include <stdio.h>
#include <syslog.h>

int main(int argc, char *argv[])
{
    syslog(LOG_INFO, "Connection from host %s", "foo.bar.dom");
    openlog("mail", LOG_PID|LOG_NDELAY, LOG_LOCAL0);
    syslog(LOG_ALERT, "who: internal error 23\n");
    setlogmask(LOG_UPTO(LOG_ERR));
    syslog(LOG_INFO|LOG_LOCAL2, "foobar error: %m");
    syslog(LOG_EMERG,   "syslogging LOG_EMERG   %d", LOG_EMERG  );
    syslog(LOG_ALERT,   "syslogging LOG_ALERT   %d", LOG_ALERT  );
    syslog(LOG_CRIT,    "syslogging LOG_CRIT    %d", LOG_CRIT   );
    syslog(LOG_ERR,     "syslogging LOG_ERR     %d", LOG_ERR    );
    syslog(LOG_WARNING, "syslogging LOG_WARNING %d", LOG_WARNING);
    syslog(LOG_NOTICE,  "syslogging LOG_NOTICE  %d", LOG_NOTICE );
    syslog(LOG_INFO,    "syslogging LOG_INFO    %d", LOG_INFO   );
    syslog(LOG_DEBUG,   "syslogging LOG_DEBUG   %d", LOG_DEBUG  );
    closelog();
    return 0;
}








